@@ -14,10 +14,10 @@ class Instrument:
     """
     Handy wrapper of instrument.db files
     """
-       
+
     tencent_addr = "https://market-data-1302861777.cos.ap-shanghai.myqcloud.com/"
     public_addr = "public/promisedland/"
-    
+
     def __init__(self, dt:str, morning:boolean = False):
         """
         Returns an instance of Instrument class for instrument.db
@@ -74,16 +74,16 @@ class Instrument:
             cmd = f"curl -o {local_db_name} {remote_url}"
             try:
                 os.system(cmd)
-            except FileNotFoundError: 
+            except FileNotFoundError:
                 self.__del__()
                 raise FileNotFoundError(f"Remote instrument db cache failed, check remote URL:{remote_url}")
         return 0
 
-    def get_contract_mapping(self, 
+    def get_contract_mapping(self,
                             tab='Options',
                             col=['code', 'type', 'strike', 'expiration', 'unit'],
                             colnames=['code', 'type', 'strike', 'expiration', 'unit']) -> pd.DataFrame:
-        
+
         """
         Return the contract mapping of an Instrument instance
 
@@ -125,7 +125,7 @@ class Instrument:
         ret.columns = colnames
         return ret
 
-    def get_tradable_contracts(self):        
+    def get_tradable_contracts(self, prefix='IF'):
         """
         Return 4 tradable Futures codes of an Instrument instance
 
@@ -137,6 +137,6 @@ class Instrument:
         """
         conn = sqlite3.connect(self.cache)
         cur = conn.cursor()
-        cur.execute(f"SELECT code FROM Futures ORDER BY code DESC LIMIT 4;")
+        cur.execute(f"SELECT code FROM Futures WHERE (Code LIKE '%{prefix}%') ORDER BY code DESC LIMIT 4;")
         ret = cur.fetchall()
         return ret
\ No newline at end of file
