@@ -3,11 +3,14 @@
 """Tests for `pitrading` package."""
 
 
-from pitrading.holidays import Holidays
+from datetime import timedelta
 import unittest
 
-from pitrading import pitrading
+import pandas as pd
 
+from pitrading import pitrading
+from pitrading.holidays import Holidays
+from pitrading.instrument import Instrument
 
 class TestPitrading(unittest.TestCase):
     """Tests for `pitrading` package."""
@@ -20,16 +23,10 @@ class TestPitrading(unittest.TestCase):
 
     def test_000_something(self):
         """Test something."""
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        Holidays.get_exp("IFXXXX")
-        
+        ds = Holidays.to_datetime('20220101')
+        while ds <= Holidays.to_datetime('20220722'):
+            if Holidays.tradingday(ds):
+                Instrument(ds.strftime('%Y%m%d'), morning=True).get_tradable_contracts()
+            ds += timedelta(days=10)
+            
+        
\ No newline at end of file
